Bloodbath Neutral Ground, New York City, New York March 2nd 2002 Nick Watkins Deck Name: frederick is not weak(ver 2.0) Description: credit for original deck design - jay kristoff of columbus, ohio Crypt (14 cards, min=6, max=18, avg=2.93) ----------------------------------------- 2x Mariana Gilbert 4 PRE cel Toreador:1 2x Gideon Fontaine 3 PRE Ventrue:1 2x Delilah Easton 2 pre Toreador:1 1x Jazz Wentworth 5 PRE dom for Ventrue:1 1x Ranjan Rishi, Camarilla Scholar 5 DOM PRE for Ventrue:2 1x Violette Prentiss 4 PRE dom Ventrue:1 1x Itzahk Levine 3 cel pre Ventrue:2 1x Frederick the Weak 2 pre Brujah antitribu:2 1x Vasilis, The Traitor of Don Cruez 2 pre Brujah:2 1x Angela Decker 1 pre Pander:2 1x Antoinette DuChamp 1 cel pre Caitiff:2 Library (89 cards) Master (18; 1 trifle) 4x Anarch Troublemaker 1x Archon Investigation 2x Barrens, The 1x Coven, The 2x Effective Management 2x Hostile Takeover 2x Information Highway 4x Presence Action (37) 2x Arson 8x Enchant Kindred 3x Entrancement 4x Intimidation 6x Media Influence 7x Mind Numb 6x Social Charm 1x Summoning, The Retainer (1) 1x Marijava Ghoul -- needed to break free-+1 stealth :) Action Modifier (11) 8x Aire of Elation 3x Change of Target Reaction (2) 2x Delaying Tactics Combat (20) 14x Catatonic Fear -- and i needed them all+majesty 6x Majesty